/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<FaceLoader.h>)
#  include <FaceLoader.h>
#endif
#if __has_include(<SensorFaceController.h>)
#  include <SensorFaceController.h>
#endif
#if __has_include(<SensorFace_p.h>)
#  include <SensorFace_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksysguard_faces()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<KSysGuard::FaceLoader>("org.kde.ksysguard.faces", 1);
    qmlRegisterTypesAndRevisions<KSysGuard::SensorFace>("org.kde.ksysguard.faces", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.ksysguard.faces", 1);
    qmlRegisterEnum<KSysGuard::SensorFace::FormFactor>("KSysGuard::SensorFace::FormFactor");
    qmlRegisterTypesAndRevisions<KSysGuard::SensorFaceController>("org.kde.ksysguard.faces", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksysguard.faces", 1, 0);
}

static const QQmlModuleRegistration orgkdeksysguardfacesRegistration("org.kde.ksysguard.faces", qml_register_types_org_kde_ksysguard_faces);
